"""Custom Widgets for this package."""


# PySide import switch
try:
    from PySide import QtGui as QtWidgets
    from PySide import QtGui
    from PySide import QtCore
except ImportError as error:
    from PySide2 import QtWidgets
    from PySide2 import QtGui
    from PySide2 import QtCore

# Import local modules
from smartEdit.mvc import gui_helper

# Icons for this package.
_ICONS = gui_helper.load_icons()


class PlusButton(QtWidgets.QToolButton):
    """Custom label that supports dropping and adds a file browser."""

    knob_dropped = QtCore.Signal(str)

    def __init__(self):
        """Initialize the DropLabel instance."""
        super(PlusButton, self).__init__()

        self.setAcceptDrops(True)
        gui_helper.set_icon(self, _ICONS["plus"])

    def dragEnterEvent(self, event):
        """Overwrite dragEnterEvent to set mimeData."""
        event.accept()

    def dragMoveEvent(self, event):
        """Overwrite dragMoveEvent to accept drags."""
        event.setDropAction(QtCore.Qt.CopyAction)
        event.accept()

    def dropEvent(self, event):
        """Fire file_dropped signal."""
        event.setDropAction(QtCore.Qt.CopyAction)
        event.accept()

        self.knob_dropped.emit(event.mimeData().text())
