"""Create widgets that can drive Nuke knobs."""


# Import built-in modules
from pydoc import locate


class KnobFactory(object):
    """Create widgets and connect with their associated controller."""

    def __init__(self, module_name, knob):
        """Initialize the KnobFactory instance.

        Args:
            module_name (str): Name of the module that resides in the widgets
                python package. We will use this module to create a view and
                connect the controller to it.

        """
        self.name = module_name
        self.knob = knob

    def create(self):
        base = "smartEdit.widgets.{}".format(self.name)
        widget = locate("{}.{}".format(base, self.name.capitalize()))

        return widget(self.knob)
